@@ -10,7 +10,6 @@ function(forn,
      Cairo=TRUE,
      printgraph = TRUE,
      legend="Dummy legend name",
-     subdiag=FALSE, subverb=FALSE,
      diagnose=FALSE, verbose=TRUE)
 {
      #                          plotdiag.residuals
@@ -29,8 +28,6 @@ function(forn,
      #          wmf          Graph title in storage space for each plot; omit ".wmf"; ".wmf" and subgroup appendix (if needed) will be added in function
      #          Cairo        TRUE causes use of Cairo graphics
      #          legend       Legend name, if needed
-     #          subdiag      Logical. TRUE causes printing of diagnostic content of called subfunctions
-     #          subverb      Logical. TRUE causes printing of subfunction ID before and after running.
      #
      #          diagnose     Logical. TRUE causes printing of diagnostic content
      #          verbose      Logical. TRUE causes printing of program ID before and after running.
@@ -55,7 +52,7 @@ function(forn,
           facetcol=NULL, facetdir, 
           mtitle, stitle, cap, horlabel, vertlabel, 
           filewidth=5, fileheight=5, legendname, 
-          highslows, subdiag, subverb)
+          highslows, diagnose, verbose)
      {
      XVAR <- data[,xcol]
      YVAR <- data[,ycol]
@@ -128,7 +125,7 @@ function(forn,
            grDevices::dev.off()
       }    # printgraph
     #
-    if(subverb) {
+    if(verbose) {
         print("", quote = F)
         print("Finished running plotD1", quote = F)
         print("", quote = F)
@@ -178,7 +175,7 @@ function(forn,
           SD <- 0
           N <- 1
           df2 <- as.data.frame(tibble::tibble(COV2, XVAR, resids, SD, N))
-                                     if(subdiag)Hmisc::prn(df2)
+                                     if(diagnose)Hmisc::prn(df2)
           wmf2 <- paste(wmf,".wmf",sep="")    
           if(grouped){
                wmf2 <- paste(wmf," Subgroup ",gg,".wmf",sep="")    
@@ -194,7 +191,7 @@ function(forn,
                      vertlabel=vl,
                      cap=caption,
                      legendname=legend,
-                     subdiag=subdiag,subverb=subverb)
+                     diagnose=diagnose,verbose=verbose)
      }
 
 
