@@ -28,7 +28,11 @@ function(x, verbose=TRUE)
      Hmisc::prn(x$"Rows by subgroup")
      print(search.history(x)[[1]])
      Hmisc::prn(x$Sigma)
+
+     print("", quote=FALSE)
+     print("Head and tail of standardized residuals arranged in columns", quote=FALSE)
      Hmisc::prn(utils::head(x$"Standardized residuals"))
+     Hmisc::prn(utils::tail(x$"Standardized residuals"))
 
      print("", quote=FALSE)
      print("Head and tail of fixed parameter estimates arranged in columns", quote=FALSE)
@@ -37,30 +41,24 @@ function(x, verbose=TRUE)
 
      print("", quote=FALSE)
      print("Head and tail of random parameter estimates arranged in columns", quote=FALSE)
-     vv<- data.frame(x$"Random parameter estimates")
-     Hmisc::prn(utils::head(vv))
-     Hmisc::prn(utils::tail(vv))
+     Hmisc::prn(utils::head(x$"Random parameter estimates"))
+     Hmisc::prn(utils::tail(x$"Random parameter estimates"))
 
+     print("", quote=FALSE)
+     print("Head and tail of leverage estimates", quote=FALSE)
      Hmisc::prn(utils::head(x$Leverage))
+     Hmisc::prn(utils::tail(x$Leverage))
+
+     print("", quote=FALSE)
      Hmisc::prn(x$"Modified Cook distance")
      Hmisc::prn(x$"t statistics")
 
+     print("", quote=FALSE)
+     print("Head and tail of fit statistics", quote=FALSE)
+     Hmisc::prn(utils::head(x$"Fit statistics"))
+     Hmisc::prn(utils::tail(x$"Fit statistics"))
 
 
-#     list("Number of rows included in Step 1"=mstart-1,
-#           Subgroups=                         groups.df1, 
-#          "Rows by subgroup"=                 df1.by.group,
-#          "Rows in stage"=                    rows.in.set,
-#           Sigma=                             sigma,
-#          "Standardized residuals"=           hold.residuals,            
-#          "Fixed parameter estimates"=        param.est,
-#          "Random parameter estimates"=       out1,
-#           Leverage=                          leverage[-1,],
-#          "Modified Cook distance"=           modCook,
-#           Dims=                              zholdlme$dims,
-#          "t statistics"=                     t.set,
-#           Call= MC)
-
      #
      if(verbose) {
           print("", quote = FALSE)
